import { symbol } from '@libp2p/interface-transport';
import { WebRTCInitiator } from '@libp2p/webrtc-peer';
import type { PeerId } from '@libp2p/interface-peer-id';
import type { Multiaddr } from '@multiformats/multiaddr';
import type { IncomingStreamData, Registrar } from '@libp2p/interface-registrar';
import type { Startable } from '@libp2p/interfaces/startable';
import type { AbortOptions } from '@libp2p/interfaces';
import type { Connection, Stream } from '@libp2p/interface-connection';
import type { ConnectionManager } from '@libp2p/interface-connection-manager';
import type { PubSub, Message } from '@libp2p/interface-pubsub';
import type { CreateListenerOptions, Listener, Transport, Upgrader } from '@libp2p/interface-transport';
import type { WebRTCSignalConfig } from './index.js';
export interface WebRTCSignalComponents {
    peerId: PeerId;
    registrar: Registrar;
    connectionManager: ConnectionManager;
    upgrader: Upgrader;
    pubsub?: PubSub;
}
export declare class WebRTCSignal implements Transport, Startable {
    private readonly components;
    private readonly init;
    private started;
    private readonly peerSignallingInputStreams;
    private readonly peerInputStream;
    private readonly dialResponseStream;
    private readonly dialResponseListener;
    constructor(components: WebRTCSignalComponents, init: WebRTCSignalConfig);
    isStarted(): boolean;
    start(): Promise<void>;
    stop(): Promise<void>;
    get [symbol](): true;
    get [Symbol.toStringTag](): 'libp2p/webrtc-signal-v1';
    _onProtocol(data: IncomingStreamData): Promise<void>;
    _handleClosedSignallingStreams(): void;
    _handleWebRTCSignalTopic(): Promise<void>;
    _handlePubSubMessage(msg: Message): void;
    dial(ma: Multiaddr, options?: AbortOptions): Promise<Connection>;
    createListener(options: CreateListenerOptions): Listener;
    filter(multiaddrs: Multiaddr[]): Multiaddr[];
    _handlePeerSignallingStream(peerId: string, signallingStream: Stream): Promise<void>;
    _connect(dstPeerId: string, options: AbortOptions): Promise<WebRTCInitiator>;
}
//# sourceMappingURL=transport.d.ts.map